printing

package
v0.0.0-...-b44d1c1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 9, 2024 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the printing type in the database.
	Label = "printing"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldRarity holds the string denoting the rarity field in the database.
	FieldRarity = "rarity"
	// EdgeArtist holds the string denoting the artist edge name in mutations.
	EdgeArtist = "artist"
	// EdgeSet holds the string denoting the set edge name in mutations.
	EdgeSet = "set"
	// EdgeCardFace holds the string denoting the card_face edge name in mutations.
	EdgeCardFace = "card_face"
	// EdgeImages holds the string denoting the images edge name in mutations.
	EdgeImages = "images"
	// Table holds the table name of the printing in the database.
	Table = "printings"
	// ArtistTable is the table that holds the artist relation/edge.
	ArtistTable = "printings"
	// ArtistInverseTable is the table name for the Artist entity.
	// It exists in this package in order to avoid circular dependency with the "artist" package.
	ArtistInverseTable = "artists"
	// ArtistColumn is the table column denoting the artist relation/edge.
	ArtistColumn = "printing_artist"
	// SetTable is the table that holds the set relation/edge.
	SetTable = "printings"
	// SetInverseTable is the table name for the Set entity.
	// It exists in this package in order to avoid circular dependency with the "set" package.
	SetInverseTable = "sets"
	// SetColumn is the table column denoting the set relation/edge.
	SetColumn = "printing_set"
	// CardFaceTable is the table that holds the card_face relation/edge.
	CardFaceTable = "printings"
	// CardFaceInverseTable is the table name for the CardFace entity.
	// It exists in this package in order to avoid circular dependency with the "cardface" package.
	CardFaceInverseTable = "card_faces"
	// CardFaceColumn is the table column denoting the card_face relation/edge.
	CardFaceColumn = "printing_card_face"
	// ImagesTable is the table that holds the images relation/edge.
	ImagesTable = "printing_images"
	// ImagesInverseTable is the table name for the PrintingImage entity.
	// It exists in this package in order to avoid circular dependency with the "printingimage" package.
	ImagesInverseTable = "printing_images"
	// ImagesColumn is the table column denoting the images relation/edge.
	ImagesColumn = "printing_image_printing"
)

Variables

var Columns = []string{
	FieldID,
	FieldRarity,
}

Columns holds all SQL columns for printing fields.

var ForeignKeys = []string{
	"printing_artist",
	"printing_set",
	"printing_card_face",
}

ForeignKeys holds the SQL foreign-keys that are owned by the "printings" table and are not defined as standalone fields in the schema.

Functions

func And

func And(predicates ...predicate.Printing) predicate.Printing

And groups predicates with the AND operator between them.

func HasArtist

func HasArtist() predicate.Printing

HasArtist applies the HasEdge predicate on the "artist" edge.

func HasArtistWith

func HasArtistWith(preds ...predicate.Artist) predicate.Printing

HasArtistWith applies the HasEdge predicate on the "artist" edge with a given conditions (other predicates).

func HasCardFace

func HasCardFace() predicate.Printing

HasCardFace applies the HasEdge predicate on the "card_face" edge.

func HasCardFaceWith

func HasCardFaceWith(preds ...predicate.CardFace) predicate.Printing

HasCardFaceWith applies the HasEdge predicate on the "card_face" edge with a given conditions (other predicates).

func HasImages

func HasImages() predicate.Printing

HasImages applies the HasEdge predicate on the "images" edge.

func HasImagesWith

func HasImagesWith(preds ...predicate.PrintingImage) predicate.Printing

HasImagesWith applies the HasEdge predicate on the "images" edge with a given conditions (other predicates).

func HasSet

func HasSet() predicate.Printing

HasSet applies the HasEdge predicate on the "set" edge.

func HasSetWith

func HasSetWith(preds ...predicate.Set) predicate.Printing

HasSetWith applies the HasEdge predicate on the "set" edge with a given conditions (other predicates).

func ID

func ID(id int) predicate.Printing

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id int) predicate.Printing

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id int) predicate.Printing

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id int) predicate.Printing

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...int) predicate.Printing

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id int) predicate.Printing

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id int) predicate.Printing

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id int) predicate.Printing

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...int) predicate.Printing

IDNotIn applies the NotIn predicate on the ID field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.Printing) predicate.Printing

Or groups predicates with the OR operator between them.

func RarityEQ

func RarityEQ(v Rarity) predicate.Printing

RarityEQ applies the EQ predicate on the "rarity" field.

func RarityIn

func RarityIn(vs ...Rarity) predicate.Printing

RarityIn applies the In predicate on the "rarity" field.

func RarityNEQ

func RarityNEQ(v Rarity) predicate.Printing

RarityNEQ applies the NEQ predicate on the "rarity" field.

func RarityNotIn

func RarityNotIn(vs ...Rarity) predicate.Printing

RarityNotIn applies the NotIn predicate on the "rarity" field.

func RarityValidator

func RarityValidator(r Rarity) error

RarityValidator is a validator for the "rarity" field enum values. It is called by the builders before save.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the Printing queries.

func ByArtistField

func ByArtistField(field string, opts ...sql.OrderTermOption) OrderOption

ByArtistField orders the results by artist field.

func ByCardFaceField

func ByCardFaceField(field string, opts ...sql.OrderTermOption) OrderOption

ByCardFaceField orders the results by card_face field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByImages

func ByImages(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByImages orders the results by images terms.

func ByImagesCount

func ByImagesCount(opts ...sql.OrderTermOption) OrderOption

ByImagesCount orders the results by images count.

func ByRarity

func ByRarity(opts ...sql.OrderTermOption) OrderOption

ByRarity orders the results by the rarity field.

func BySetField

func BySetField(field string, opts ...sql.OrderTermOption) OrderOption

BySetField orders the results by set field.

type Rarity

type Rarity string

Rarity defines the type for the "rarity" enum field.

const (
	RarityCommon   Rarity = "common"
	RarityUncommon Rarity = "uncommon"
	RarityRare     Rarity = "rare"
	RarityMythic   Rarity = "mythic"
)

Rarity values.

func (Rarity) String

func (r Rarity) String() string

Jump to