Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.Printing) predicate.Printing
- func HasArtist() predicate.Printing
- func HasArtistWith(preds ...predicate.Artist) predicate.Printing
- func HasCardFace() predicate.Printing
- func HasCardFaceWith(preds ...predicate.CardFace) predicate.Printing
- func HasImages() predicate.Printing
- func HasImagesWith(preds ...predicate.PrintingImage) predicate.Printing
- func HasSet() predicate.Printing
- func HasSetWith(preds ...predicate.Set) predicate.Printing
- func ID(id int) predicate.Printing
- func IDEQ(id int) predicate.Printing
- func IDGT(id int) predicate.Printing
- func IDGTE(id int) predicate.Printing
- func IDIn(ids ...int) predicate.Printing
- func IDLT(id int) predicate.Printing
- func IDLTE(id int) predicate.Printing
- func IDNEQ(id int) predicate.Printing
- func IDNotIn(ids ...int) predicate.Printing
- func Not(p predicate.Printing) predicate.Printing
- func Or(predicates ...predicate.Printing) predicate.Printing
- func RarityEQ(v Rarity) predicate.Printing
- func RarityIn(vs ...Rarity) predicate.Printing
- func RarityNEQ(v Rarity) predicate.Printing
- func RarityNotIn(vs ...Rarity) predicate.Printing
- func RarityValidator(r Rarity) error
- func ValidColumn(column string) bool
- type OrderOption
- func ByArtistField(field string, opts ...sql.OrderTermOption) OrderOption
- func ByCardFaceField(field string, opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByImages(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByImagesCount(opts ...sql.OrderTermOption) OrderOption
- func ByRarity(opts ...sql.OrderTermOption) OrderOption
- func BySetField(field string, opts ...sql.OrderTermOption) OrderOption
- type Rarity
Constants ¶
const ( // Label holds the string label denoting the printing type in the database. Label = "printing" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldRarity holds the string denoting the rarity field in the database. FieldRarity = "rarity" // EdgeArtist holds the string denoting the artist edge name in mutations. EdgeArtist = "artist" // EdgeSet holds the string denoting the set edge name in mutations. EdgeSet = "set" // EdgeCardFace holds the string denoting the card_face edge name in mutations. EdgeCardFace = "card_face" // EdgeImages holds the string denoting the images edge name in mutations. EdgeImages = "images" // Table holds the table name of the printing in the database. Table = "printings" // ArtistTable is the table that holds the artist relation/edge. ArtistTable = "printings" // ArtistInverseTable is the table name for the Artist entity. // It exists in this package in order to avoid circular dependency with the "artist" package. ArtistInverseTable = "artists" // ArtistColumn is the table column denoting the artist relation/edge. ArtistColumn = "printing_artist" // SetTable is the table that holds the set relation/edge. SetTable = "printings" // SetInverseTable is the table name for the Set entity. // It exists in this package in order to avoid circular dependency with the "set" package. SetInverseTable = "sets" // SetColumn is the table column denoting the set relation/edge. SetColumn = "printing_set" // CardFaceTable is the table that holds the card_face relation/edge. CardFaceTable = "printings" // CardFaceInverseTable is the table name for the CardFace entity. // It exists in this package in order to avoid circular dependency with the "cardface" package. CardFaceInverseTable = "card_faces" // CardFaceColumn is the table column denoting the card_face relation/edge. CardFaceColumn = "printing_card_face" // ImagesTable is the table that holds the images relation/edge. ImagesTable = "printing_images" // ImagesInverseTable is the table name for the PrintingImage entity. // It exists in this package in order to avoid circular dependency with the "printingimage" package. ImagesInverseTable = "printing_images" // ImagesColumn is the table column denoting the images relation/edge. ImagesColumn = "printing_image_printing" )
Variables ¶
var Columns = []string{ FieldID, FieldRarity, }
Columns holds all SQL columns for printing fields.
var ForeignKeys = []string{
"printing_artist",
"printing_set",
"printing_card_face",
}
ForeignKeys holds the SQL foreign-keys that are owned by the "printings" table and are not defined as standalone fields in the schema.
Functions ¶
func HasArtistWith ¶
HasArtistWith applies the HasEdge predicate on the "artist" edge with a given conditions (other predicates).
func HasCardFace ¶
HasCardFace applies the HasEdge predicate on the "card_face" edge.
func HasCardFaceWith ¶
HasCardFaceWith applies the HasEdge predicate on the "card_face" edge with a given conditions (other predicates).
func HasImagesWith ¶
func HasImagesWith(preds ...predicate.PrintingImage) predicate.Printing
HasImagesWith applies the HasEdge predicate on the "images" edge with a given conditions (other predicates).
func HasSetWith ¶
HasSetWith applies the HasEdge predicate on the "set" edge with a given conditions (other predicates).
func RarityNotIn ¶
RarityNotIn applies the NotIn predicate on the "rarity" field.
func RarityValidator ¶
RarityValidator is a validator for the "rarity" field enum values. It is called by the builders before save.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the Printing queries.
func ByArtistField ¶
func ByArtistField(field string, opts ...sql.OrderTermOption) OrderOption
ByArtistField orders the results by artist field.
func ByCardFaceField ¶
func ByCardFaceField(field string, opts ...sql.OrderTermOption) OrderOption
ByCardFaceField orders the results by card_face field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByImages ¶
func ByImages(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByImages orders the results by images terms.
func ByImagesCount ¶
func ByImagesCount(opts ...sql.OrderTermOption) OrderOption
ByImagesCount orders the results by images count.
func ByRarity ¶
func ByRarity(opts ...sql.OrderTermOption) OrderOption
ByRarity orders the results by the rarity field.
func BySetField ¶
func BySetField(field string, opts ...sql.OrderTermOption) OrderOption
BySetField orders the results by set field.